==> haskell-uri-bytestring-0.3.3.1-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-C4p9zaIvtDS8GFXRKur0pL
key:                  uri-bytestring-0.3.3.1-C4p9zaIvtDS8GFXRKur0pL
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  39911f401d0f3aae6d07b2ec9ef56812
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-C4p9zaIvtDS8GFXRKur0pL
depends:
    attoparsec-0.14.4-2WnTlN46elo3llwbGCF7aS base-4.17.2.1
    blaze-builder-0.4.3-6IYx8eSaGHUJnwII0Up24j bytestring-0.11.5.3
    containers-0.6.7 template-haskell-2.19.0.0
    th-lift-instances-0.1.20-IrFuy1F8A85FoBrEkfwl08

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.3.1-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-XFbsRsdSzH6lVABWy06Uo
key:                  uri-bytestring-0.3.3.1-XFbsRsdSzH6lVABWy06Uo
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  b09e52f91a070697de903a0e4118a291
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-XFbsRsdSzH6lVABWy06Uo
depends:
    attoparsec-0.14.4-AS2Ju05FAjs55rPAuL3miO base-4.17.2.1
    blaze-builder-0.4.3-4yy7EUiUNtIb1TX5lPJzq bytestring-0.11.5.3
    containers-0.6.7 template-haskell-2.19.0.0
    th-lift-instances-0.1.20-AeUdbWqQ7Hq4NSZBSNUP4Q

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
